mpmath: Pure Python library for multiprecision floating-point arithmetic
========================================================================

Description
-----------

Mpmath is a pure-Python library for multiprecision floating-point
arithmetic. It provides an extensive set of transcendental functions,
unlimited exponent sizes, complex numbers, interval arithmetic,
numerical integration and differentiation, root-finding, linear algebra,
and much more. Almost any calculation can be performed just as well at
10-digit or 1000-digit precision, and in many cases mpmath implements
asymptotically fast algorithms that scale well for extremely high
precision work. If available, mpmath will (optionally) use gmpy to speed
up high precision operations.


Upstream Contact
----------------

-  Author: Fredrik Johansson
-  Email: fredrik.johansson@gmail.com
-  http://mpmath.org
-  Website: https://github.com/fredrik-johansson/mpmath/

